@@ -76,9 +76,9 @@ class Api(object):
 
     def get_test_state(self, key):
         return self.db_client.benchmark_resource.get_test_state(key)
-#
-#
-# if __name__ == '__main__':
-#     API = Api()
-#     a = API.get_node_info()
-#     pass
+
+
+if __name__ == '__main__':
+    API = Api()
+    a = API.get_node_info()
+    print(a)
