@@ -8,6 +8,9 @@ class TestDBResource(object):
     def __init__(self, db_name="production_test"):
         self.sql = SqlConnection(db_name=db_name)
 
+    def __del__(self):
+        del self.sql
+
     def get_result(self, key):
         cmd = "SELECT * FROM test_results WHERE test_key='{}'".format(key)
         self.sql.cursor.execute(cmd)
@@ -34,8 +37,8 @@ class TestDBResource(object):
             tests.append(test)
         return tests
 
-
-if __name__ == '__main__':
-    DB = TestDBResource()
-    tests1 = DB.get_tests_by_ip("172.29.131.80", 100)
-    pass
\ No newline at end of file
+#
+# if __name__ == '__main__':
+#     DB = TestDBResource()
+#     tests1 = DB.get_tests_by_ip("172.29.131.80", 100)
+#     pass
