@@ -25,11 +25,11 @@ class RestClient(object):
         self.stop_flag = StopFlagResource(host, port, __session, time_out)
 
 
-#
-# R = RestClient("172.29.130.138")
-# a = R.stop_flag.get_stop_flag()
-# R.stop_flag.set_stop_flag(False)
-# b = R.stop_flag.get_stop_flag()
-# R.stop_flag.set_stop_flag(True)
-# c = R.stop_flag.get_stop_flag()
-# pass
+
+R = RestClient("172.29.130.138")
+a = R.stop_flag.get_stop_flag()
+R.stop_flag.set_stop_flag(False)
+b = R.stop_flag.get_stop_flag()
+d = R.stop_flag.set_stop_flag(True)
+c = R.stop_flag.get_stop_flag()
+pass
